@@ -328,8 +328,8 @@ alerts_box <- box(
     collapsible = TRUE,
     width       = 12,
     p("Alerts can be added with the following code in the server:"),
-    blockQuote(tags$pre("S:periscope2::createAlert(id = 'alert place',
-                         options = list(title    = 'alert title',
+    blockQuote(tags$pre("S:periscope2::createPSAlert(id = 'alert place',
+                         options  = list(title    = 'alert title',
                          status   = 'alert status'',
                          closable = TRUE,
                          content  = alert contents))"), color = "info"),
@@ -423,35 +423,41 @@ style_guide_box <- box(
     tags$li("Blank, empty or invalid values will use the default values"),
     br(),
     fluidRow(column(width = 6,
-                    colourInput(inputId = "primary_picker",
-                                label   = ui_tooltip(id    = "primary_tip",
-                                                     label = "Primary",
-                                                     text  = "Set app 'Primary' color"))),
+                    colourInput(inputId          = "primary_picker",
+                                allowTransparent = TRUE,
+                                label            = ui_tooltip(id    = "primary_tip",
+                                                              label = "Primary",
+                                                              text  = "Set app 'Primary' color"))),
              column(width = 6,
-                    colourInput(inputId = "secondary_picker",
-                                label   = ui_tooltip(id    = "secondary_tip",
-                                                     label = "Secondary",
-                                                     text  = "Set app 'Secondary' color")))),
+                    colourInput(inputId          = "secondary_picker",
+                                allowTransparent = TRUE,
+                                label            = ui_tooltip(id    = "secondary_tip",
+                                                              label = "Secondary",
+                                                              text  = "Set app 'Secondary' color")))),
     fluidRow(column(width = 6,
-                    colourInput(inputId = "success_picker",
-                                label   = ui_tooltip(id    = "success_tip",
-                                                     label = "Success",
-                                                     text  = "Set app 'Success' color"))),
+                    colourInput(inputId          = "success_picker",
+                                allowTransparent = TRUE,
+                                label            = ui_tooltip(id    = "success_tip",
+                                                              label = "Success",
+                                                              text  = "Set app 'Success' color"))),
              column(width = 6,
-                    colourInput(inputId = "info_picker",
-                                label   = ui_tooltip(id    = "info_tip",
-                                                     label = "Info",
-                                                     text  = "Set app 'Info' color")))),
+                    colourInput(inputId          = "info_picker",
+                                allowTransparent = TRUE,
+                                label            = ui_tooltip(id    = "info_tip",
+                                                              label = "Info",
+                                                              text  = "Set app 'Info' color")))),
     fluidRow(column(width = 6,
-                    colourInput(inputId = "warning_picker",
-                                label   = ui_tooltip(id    = "warning_tip",
-                                                     label = "Warning",
-                                                     text  = "Set app 'Warning' color"))),
+                    colourInput(inputId          = "warning_picker",
+                                allowTransparent = TRUE,
+                                label            = ui_tooltip(id    = "warning_tip",
+                                                              label = "Warning",
+                                                              text  = "Set app 'Warning' color"))),
              column(width = 6,
-                    colourInput(inputId = "danger_picker",
-                                label   = ui_tooltip(id    = "danger_tip",
-                                                     label = "Danger",
-                                                     text  = "Set app 'Danger' color")))),
+                    colourInput(inputId          = "danger_picker",
+                                allowTransparent = TRUE,
+                                label            = ui_tooltip(id    = "danger_tip",
+                                                              label = "Danger",
+                                                              text  = "Set app 'Danger' color")))),
     hr(),
     tags$dt("Sidebars Width"),
     tags$li("Width or padding is to be specified as a numeric value in pixels. Must be greater than 0 and include numbers only"),
@@ -477,35 +483,41 @@ style_guide_box <- box(
     tags$li("Blank, empty or invalid values will the use the default values"),
     br(),
     fluidRow(column(width = 6,
-                    colourInput(inputId = "background_color_picker",
-                                label   = ui_tooltip(id    = "background_tip",
-                                                     label = "Background Color",
-                                                     text  = "Set app background color"))),
+                    colourInput(inputId          = "background_color_picker",
+                                allowTransparent = TRUE,
+                                label            = ui_tooltip(id    = "background_tip",
+                                                              label = "Background Color",
+                                                              text  = "Set app background color"))),
              column(width = 6,
-                    colourInput(inputId = "sidebar_background_color_picker",
-                                label   = ui_tooltip(id    = "sidebars_background_tip",
-                                                     label = "Sidebars Background",
-                                                     text  = "Set app sidebars background color")))),
+                    colourInput(inputId          = "sidebar_background_color_picker",
+                                allowTransparent = TRUE,
+                                label            = ui_tooltip(id    = "sidebars_background_tip",
+                                                              label = "Sidebars Background",
+                                                              text  = "Set app sidebars background color")))),
     fluidRow(column(width = 6,
-                    colourInput(inputId = "sidebar_background_hover_color_picker",
-                                label   = ui_tooltip(id    = "sidebar_background_hover_tip",
-                                                     label = "Sidebars Background Hover",
-                                                     text  = "Set app sidebars background hover color"))),
+                    colourInput(inputId          = "sidebar_background_hover_color_picker",
+                                allowTransparent = TRUE,
+                                label            = ui_tooltip(id    = "sidebar_background_hover_tip",
+                                                              label = "Sidebars Background Hover",
+                                                              text  = "Set app sidebars background hover color"))),
              column(width = 6,
-                    colourInput(inputId = "sidebar_hover_color_picker",
-                                label   = ui_tooltip(id    = "sidebar_hover_tip",
-                                                     label = "Sidebars Hover",
-                                                     text  = "Set app sidebars hover color")))),
+                    colourInput(inputId          = "sidebar_hover_color_picker",
+                                allowTransparent = TRUE,
+                                label            = ui_tooltip(id    = "sidebar_hover_tip",
+                                                              label = "Sidebars Hover",
+                                                              text  = "Set app sidebars hover color")))),
     fluidRow(column(width = 6,
-                    colourInput(inputId = "sidebar_color_picker",
-                                label   = ui_tooltip(id    = "sidebar_tip",
-                                                     label = "Sidebars",
-                                                     text  = "Set app sidebars  color"))),
+                    colourInput(inputId          = "sidebar_color_picker",
+                                allowTransparent = TRUE,
+                                label            = ui_tooltip(id    = "sidebar_tip",
+                                                              label = "Sidebars",
+                                                              text  = "Set app sidebars  color"))),
              column(width = 6,
-                    colourInput(inputId = "sidebar_active_color_picker",
-                                label   = ui_tooltip(id    = "sidebar_active_tip",
-                                                     label = "Sidebars Active",
-                                                     text  = "Set app sidebars active color")))),
+                    colourInput(inputId          = "sidebar_active_color_picker",
+                                allowTransparent = TRUE,
+                                label            = ui_tooltip(id    = "sidebar_active_tip",
+                                                              label = "Sidebars Active",
+                                                              text  = "Set app sidebars active color")))),
     hr(),
     fluidRow(column(width = 6,
                     actionButton(inputId = "update_app_theme",
